@@ -15,11 +15,21 @@ from starlite.config import (
 from starlite.connection import ASGIConnection, Request, WebSocket
 from starlite.controller import Controller
 from starlite.datastructures import (
+    AbstractAsyncClassicPaginator,
+    AbstractAsyncCursorPaginator,
+    AbstractAsyncOffsetPaginator,
+    AbstractSyncClassicPaginator,
+    AbstractSyncCursorPaginator,
+    AbstractSyncOffsetPaginator,
     BackgroundTask,
     BackgroundTasks,
+    ClassicPagination,
     Cookie,
+    CursorPagination,
     File,
     FormMultiDict,
+    ImmutableState,
+    OffsetPagination,
     Provide,
     Redirect,
     ResponseContainer,
@@ -81,6 +91,7 @@ from starlite.plugins import PluginProtocol
 from starlite.response import Response
 from starlite.router import Router
 from starlite.routes import ASGIRoute, BaseRoute, HTTPRoute, WebSocketRoute
+from starlite.security import AbstractSecurityConfig
 from starlite.testing.create_test_client import create_test_client
 from starlite.testing.test_client import TestClient
 from starlite.types.partial import Partial
@@ -89,8 +100,15 @@ __all__ = (
     "ASGIConnection",
     "ASGIRoute",
     "ASGIRouteHandler",
+    "AbstractAsyncClassicPaginator",
+    "AbstractAsyncCursorPaginator",
+    "AbstractAsyncOffsetPaginator",
     "AbstractAuthenticationMiddleware",
     "AbstractMiddleware",
+    "AbstractSecurityConfig",
+    "AbstractSyncClassicPaginator",
+    "AbstractSyncCursorPaginator",
+    "AbstractSyncOffsetPaginator",
     "AllowedHostsConfig",
     "AuthenticationResult",
     "BackgroundTask",
@@ -102,9 +120,11 @@ __all__ = (
     "CORSConfig",
     "CSRFConfig",
     "CacheConfig",
+    "ClassicPagination",
     "CompressionConfig",
     "Controller",
     "Cookie",
+    "CursorPagination",
     "DTOFactory",
     "DefineMiddleware",
     "Dependency",
@@ -114,6 +134,7 @@ __all__ = (
     "HTTPRoute",
     "HTTPRouteHandler",
     "HttpMethod",
+    "ImmutableState",
     "ImproperlyConfiguredException",
     "InternalServerException",
     "LoggingConfig",
@@ -123,6 +144,7 @@ __all__ = (
     "NoRouteMatchFoundException",
     "NotAuthorizedException",
     "NotFoundException",
+    "OffsetPagination",
     "OpenAPIConfig",
     "OpenAPIController",
     "OpenAPIMediaType",
