@@ -22,7 +22,7 @@ def traverse_route_map(
         path: The request's path.
 
     Raises:
-         NotFoundException: if no correlating node is found.
+        NotFoundException: If no correlating node is found.
 
     Returns:
         A tuple containing the target RouteMapNode and a list containing all path parameter values.
@@ -61,6 +61,9 @@ def parse_node_handlers(
         node: The trie node to parse.
         method: The scope's method.
 
+    Raises:
+        KeyError: If no matching method is found.
+
     Returns:
         An ASGI Handler tuple.
     """
@@ -82,6 +85,9 @@ def parse_path_params(
         parameter_definitions: The parameter definitions tuple from the route.
         path_param_values: The string values extracted from the url
 
+    Raises:
+        ValueError: If any of path parameters can not be parsed into a value.
+
     Returns:
         A dictionary of parsed path parameters.
     """
@@ -111,6 +117,7 @@ def parse_path_to_route(
 
     Raises:
         MethodNotAllowedException: if no matching method is found.
+        NotFoundException: If no correlating node is found or if path params can not be parsed into values according to the node definition.
 
     Returns:
         A tuple containing the stack of middlewares and the route handler that is wrapped by it.
@@ -129,7 +136,10 @@ def parse_path_to_route(
             # any such handler.
             if not mount_node.children or not any(sub_route in path for sub_route in mount_node.children):  # type: ignore
                 asgi_app, handler = parse_node_handlers(node=mount_node, method=method)
-                return asgi_app, handler, remaining_path or "/", {}
+                remaining_path = remaining_path or "/"
+                if not mount_node.is_static:
+                    remaining_path = remaining_path if remaining_path.endswith("/") else f"{remaining_path}/"
+                return asgi_app, handler, remaining_path, {}
 
         node, path_parameters, path = traverse_route_map(
             root_node=root_node,
