@@ -14,13 +14,13 @@ from typing import (
     cast,
 )
 
-from orjson import dumps
 from pydantic import BaseModel, Field, validator
 
 from starlite.exceptions import (
     ImproperlyConfiguredException,
     MissingDependencyException,
 )
+from starlite.utils.serialization import encode_json
 
 if TYPE_CHECKING:
     from typing import NoReturn
@@ -123,10 +123,7 @@ class LoggingConfig(BaseLoggingConfig, BaseModel):
     handlers: Dict[str, Dict[str, Any]] = Field(default_factory=get_default_handlers)
     """A dict in which each key is a handler id and each value is a dict describing how to configure the corresponding Handler instance."""
     loggers: Dict[str, Dict[str, Any]] = {
-        "starlite": {
-            "level": "INFO",
-            "handlers": ["queue_listener"],
-        },
+        "starlite": {"level": "INFO", "handlers": ["queue_listener"], "propagate": False},
     }
     """A dict in which each key is a logger name and each value is a dict describing how to configure the corresponding Logger instance."""
     root: Dict[str, Union[Dict[str, Any], List[Any], str]] = {
@@ -179,7 +176,7 @@ class LoggingConfig(BaseLoggingConfig, BaseModel):
             A 'logging.getLogger' like function.
         """
 
-        if "picologging" in str(dumps(self.handlers)):
+        if "picologging" in str(encode_json(self.handlers)):
             try:
                 from picologging import config, getLogger
             except ImportError as e:  # pragma: no cover
@@ -210,7 +207,7 @@ def default_structlog_processors() -> Optional[List[Processor]]:  # pyright: ign
             structlog.processors.add_log_level,
             structlog.processors.format_exc_info,
             structlog.processors.TimeStamper(fmt="iso"),
-            structlog.processors.JSONRenderer(serializer=dumps),
+            structlog.processors.JSONRenderer(serializer=encode_json),
         ]
     except ImportError:  # pragma: no cover
         return None
